Module clap

Module clap 

Public module for share clap pieces to reduce duplication

Structs

GrpcOptions
StorageOptions
Collection of per usage storage backend configurations, plus store write-path tuning.

Functions

duration_to_human_readable_string