pub struct GrpcOptionsExternal {
pub request_timeout: Duration,
pub max_connection_age: Duration,
pub burst_size: NonZeroU32,
pub replenish_n_per_second_per_ip: NonZeroU64,
pub max_concurrent_connections: u64,
}Fields
request_timeout: DurationMaximum duration a gRPC request is allocated before being dropped by the server.
This may occur if the server is overloaded or due to an internal bug.
max_connection_age: DurationMaximum duration of a connection before we drop it on the server side irrespective of activity.
burst_size: NonZeroU32Number of connections to be served before the “API tokens” need to be replenished per IP address.
replenish_n_per_second_per_ip: NonZeroU64Number of request credits replenished per second per IP.
max_concurrent_connections: u64Maximum number of concurrent connections accepted by the server.
Implementations