pub struct GrpcOptionsInternal {
pub request_timeout: Duration,
}Fields
request_timeout: DurationMaximum duration a gRPC request is allocated before being dropped by the server.
This may occur if the server is overloaded or due to an internal bug.
Implementations