Module genesis

Module genesis 

Structs

GenesisBlock
A validated genesis block and its protocol configuration.

Enums

OfficialNetwork
Official Miden networks with a hosted genesis block.

Functions

fetch_genesis_block
Downloads a trusted genesis block and its protocol configuration for an official Miden network.
read_genesis_block
Reads a trusted genesis block and its protocol configuration from disk.