pub fn rate_limit_per_ip(
grpc_options: GrpcOptionsExternal,
) -> Result<GovernorLayer<SmartIpKeyExtractor, StateInformationMiddleware, Body>>Expand description
Creates a per-IP rate limit layer using the configured governor settings.
pub fn rate_limit_per_ip(
grpc_options: GrpcOptionsExternal,
) -> Result<GovernorLayer<SmartIpKeyExtractor, StateInformationMiddleware, Body>>Creates a per-IP rate limit layer using the configured governor settings.