Module logging

Module logging 

Structs

OtelGuard
A guard that shuts down the tracer provider when dropped. This ensures that the logs are flushed to the exporter before the program exits.
ResourceConfig
Default OpenTelemetry resource attributes for this process.

Enums

OpenTelemetry
Configures setup_tracing to enable or disable the open-telemetry exporter.

Functions

setup_tracing
Initializes tracing to stdout and optionally an open-telemetry exporter.