Module shutdown

Module shutdown 

Structs

CancellationToken
A token which can be used to signal a cancellation request to one or more tasks.

Constants

GRACE_PERIOD
Time allowed for services to finish after a shutdown signal before the process exits.

Functions

run_with_shutdown
Runs a service future until it completes or a shutdown signal is received.
shutdown_signal
Waits for SIGTERM or Ctrl-C.