Module genesis

Module genesis 

Enums

OfficialNetwork
Official Miden networks with a hosted genesis block.

Constants

INSECURE_VALIDATOR_SIGNING_KEY_HEX
A predefined, insecure validator signing key for development purposes.

Functions

fetch_genesis_block
Downloads a trusted genesis block for an official Miden network.
read_genesis_block
Reads a trusted genesis block from disk.