Module grpc

Module grpc 

Structs

ClientIp
The originating client IP, resolved by ResolveClientIpLayer and stored in a request’s extensions.
GrpcIpExtractor
Wraps SmartIpKeyExtractor by providing a fallback to the client IP address provided by the gRPC transport.
ResolveClientIp
The service produced by ResolveClientIpLayer.
ResolveClientIpLayer
A tower::Layer that resolves the originating client IP and stores it in the request’s extensions as ClientIp.

Traits

UrlExt
A sealed extension trait for url::Url that adds convenience functions for binding and connecting to the url.

Functions

rate_limit_concurrent_connections
Builds a global concurrency limit layer using the configured semaphore.
rate_limit_per_ip
Creates a per-IP rate limit layer using the configured governor settings.