Module grpc

Module grpc 

Structs

GrpcIpExtractor
Wraps SmartIpKeyExtractor by providing a fallback to the client IP address provided by the gRPC transport.

Traits

UrlExt
A sealed extension trait for url::Url that adds convenience functions for binding and connecting to the url.

Functions

rate_limit_concurrent_connections
Builds a global concurrency limit layer using the configured semaphore.
rate_limit_per_ip
Creates a per-IP rate limit layer using the configured governor settings.