Structs
- Grpc
IpExtractor - Wraps
SmartIpKeyExtractorby providing a fallback to the client IP address provided by the gRPC transport.
Traits
- UrlExt
- A sealed extension trait for
url::Urlthat adds convenience functions for binding and connecting to the url.
Functions
- rate_
limit_ concurrent_ connections - Builds a global concurrency limit layer using the configured semaphore.
- rate_
limit_ per_ ip - Creates a per-IP rate limit layer using the configured governor settings.