setup_tracing

Function setup_tracing 

pub fn setup_tracing(otel: OpenTelemetry) -> Result<()>
Initializes tracing to stdout and optionally an open-telemetry exporter.

Trace filtering defaults to INFO and can be configured using the conventional RUST_LOG environment variable.

The open-telemetry configuration is controlled via environment variables as defined in the specification

Registers a panic hook so that panic errors are reported to the open-telemetry exporter.