Structs
- Cancellation
Token - A token which can be used to signal a cancellation request to one or more tasks.
Constants
- GRACE_
PERIOD - Time allowed for services to finish after a shutdown signal before the process exits.
Functions
- run_
with_ shutdown - Runs a service future until it completes or a shutdown signal is received.
- shutdown_
signal - Waits for SIGTERM or Ctrl-C.