pub struct Tasks { /* private fields */ }Expand description
A named task set for supervising concurrently-running Tokio tasks.
Dropping a task set aborts all tasks that are still running.
Implementations
Sourceimpl Tasks
impl Tasks
Sourcepub fn spawn(
&mut self,
name: impl Into<String>,
task: impl Future<Output = Result<()>> + Send + 'static,
) -> Id
pub fn spawn( &mut self, name: impl Into<String>, task: impl Future<Output = Result<()>> + Send + 'static, ) -> Id
Spawns a named task into the set.
Sourcepub fn spawn_infallible(
&mut self,
name: impl Into<String>,
task: impl Future<Output = ()> + Send + 'static,
) -> Id
pub fn spawn_infallible( &mut self, name: impl Into<String>, task: impl Future<Output = ()> + Send + 'static, ) -> Id
Spawns a named task that does not return an error.
Sourcepub async fn join_next(
&mut self,
) -> Option<(String, Result<Result<()>, JoinError>)>
pub async fn join_next( &mut self, ) -> Option<(String, Result<Result<()>, JoinError>)>
Waits for the next task to complete.
Sourcepub async fn join_next_as_error(&mut self) -> Result<()>
pub async fn join_next_as_error(&mut self) -> Result<()>
Waits for the next task to complete, treating that completion as an error.
This is intended for supervised task sets where every task is expected to run indefinitely.